package com.cyl.manager.ums.service;

import java.util.List;
import com.cyl.manager.ums.domain.MemberDoorLock;

/**
 * 门锁信息Service接口
 * 
 * @author daixiande
 */
public interface MemberDoorLockService {
    /**
     * 查询门锁信息
     * 
     * @param id 门锁信息主键
     * @return 门锁信息
     */
    MemberDoorLock selectMemberDoorLockById(Long id);

    /**
     * 查询门锁信息列表
     * 
     * @param memberDoorLock 门锁信息
     * @return 门锁信息集合
     */
    List<MemberDoorLock> selectMemberDoorLockList(MemberDoorLock memberDoorLock);

    /**
     * 新增门锁信息
     * 
     * @param memberDoorLock 门锁信息
     * @return 结果
     */
    int insertMemberDoorLock(MemberDoorLock memberDoorLock);

    /**
     * 修改门锁信息
     * 
     * @param memberDoorLock 门锁信息
     * @return 结果
     */
    int updateMemberDoorLock(MemberDoorLock memberDoorLock);

    /**
     * 批量删除门锁信息
     * 
     * @param ids 需要删除的门锁信息主键集合
     * @return 结果
     */
    int deleteMemberDoorLockByIds(Long[] ids);

    /**
     * 删除门锁信息信息
     * 
     * @param id 门锁信息主键
     * @return 结果
     */
    int deleteMemberDoorLockById(Long id);
}
